@@ -52,8 +52,6 @@ extern int	errno;
 
 static int check_uniqueness(int retain);
 
-static struct kmouse_options kopt;
-
 /*===================================================================*
  *     ==>    the logging utility
  *
@@ -156,8 +154,13 @@ static int loadlut(char *charset)
       inwordLut[c>>5] |= 1 << (c&0x1F);
     }
   
-  if ((fd=open("/dev/console", O_WRONLY)) < 0) /* console is allright */
-    oops("/dev/console");
+  if ((fd=open(consolename, O_WRONLY)) < 0)
+    {
+    /* try /dev/console, if /dev/tty0 failed */
+    consolename="/dev/console";
+    if ((fd=open(consolename, O_WRONLY)) < 0)
+      oops(consolename);
+    }
   if ((fd<0) || (ioctl(fd, TIOCLINUX, &long_array)<0))
     {
     if (errno==EPERM && getuid())
@@ -251,6 +254,7 @@ static int usage(char *whofailed)
  "    -R               enter repeater mode. X should read /dev/gpmdata\n"
  "                     like it was a MouseSystem mouse device\n"
  "    -s sample-rate   sets the sample rate (default %d)\n"
+ "    -S [commands]    enable special commands (see man page)\n"
  "    -t mouse-type    sets mouse type (default '%s')\n"
  "                     Use an unexistent type (e.g. \"help\") to get a list\n"
  "    -T               test: read mouse, no clients\n"
@@ -319,7 +323,7 @@ return 0; /* never */
 /*===================================================================*/
 int cmdline(int argc, char **argv)
 {
-char options[]="a:b:B:d:Dg:hi:Kkl:L:m:Mo:pqr:Rs:t:Tv23";
+char options[]="a:b:B:d:Dg:hi:Kkl:L:m:Mo:pqr:Rs:S:t:Tv23";
 int i, opt, fd, kfd;
 struct kmouse_options koptions;
 FILE *f;
@@ -372,6 +376,10 @@ static struct {char *in; char *out;} seq[] = {
 	  break;
       case 'R': opt_repeater++; break;
       case 's': opt_sample = atoi(optarg); break;
+      case 'S':
+          if (optarg) opt_special=optarg;
+          else opt_special="";
+          break;
       case 't': opt_type=optarg; opt_explicittype++; break;
       case 'T': opt_test++; break;
       case 'v': printf(GPM_NAME " " GPM_RELEASE ", " GPM_DATE "\n"); exit(0);
@@ -552,7 +560,8 @@ static struct {char *in; char *out;} seq[] = {
     }
   if (KMOUSE_V_MAJOR(i) != KMOUSE_V_MAJOR(KMOUSE_VERSION_N))
     {
-    fprintf(stderr,"%s: kmouse version %i.%i not supoorted: %i.xx needed\n",
+    fprintf(stderr,"%s: kmouse version %i.%i not supported: %i.xx needed\n",
+	    prgname,
 	    KMOUSE_V_MAJOR(i),KMOUSE_V_MINOR(i),
 	    KMOUSE_V_MAJOR(KMOUSE_VERSION_N));
     exit(1);
