@@ -231,7 +231,7 @@ static int M_mman(Gpm_Event *state,  unsigned char *data)
 static int M_wacom(Gpm_Event *state, unsigned char *data)
 {
   static int ox=-1, oy, threshold=8;
-  int x, y, z, p;
+  int x, y, z;
 
   if (data[0]==0xa0) /* leave -- but sometimes it's not decoded */
     { ox=-1; state->buttons=0; state->dx=state->dy=0; return 0;}
@@ -447,7 +447,7 @@ static Gpm_Type *I_wacom(int fd, unsigned short flags, struct Gpm_Type *type)
 {
   int i;
 
-  if (opt_baud=1200) opt_baud=9600; /* default to 9600 */
+  if (opt_baud == 1200) opt_baud=9600; /* default to 9600 */
   /* change from any available speed to the chosen one */
   for (i=9600; i>=1200; i/=2)
     setspeed(fd, i, opt_baud, flags);
@@ -463,6 +463,22 @@ static Gpm_Type *I_wacom(int fd, unsigned short flags, struct Gpm_Type *type)
  * Note that mman must be the first, and ms the second (I use this info
  * in mouse-test.c, as a quick and dirty hack
  */
+
+ /*
+  * For those who are trying to add a new type, here some docs:
+  *
+  * The first three strings are the name, an help line, a long name (if any)
+  * Then come the function: the decoder and the initializazion function
+  * The PROTO_* field is an id label, from kmouse.h, and then come the
+  *     flags to pass to the serial port.
+  * Follows an array of four bytes: it is the protocol-identification, based
+  *     on the first two bytes of a packet: if
+  *     "((byte0 & proto[0]) == proto[1]) && ((byte1 & proto[2]) == proto[3])"
+  *     then we are at the beginning of a packet.
+  * The last numbers are: bytes-per-packet bytes-to-read() does-get-extra-byte
+  *     and is-absolute-coordinates. The last two are booleans
+  */
+
 Gpm_Type mice[]={
   {"mman", "The \"MouseMan\" and similar devices (3/4 bytes per packet).",
            "Mouseman", M_mman, I_serial, PROTO_MMAN, CS7 | STD_FLG, /* first */
@@ -495,7 +511,7 @@ Gpm_Type mice[]={
            "", M_ncr, NULL, PROTO_NCR, STD_FLG,
                                 {0x08, 0x08, 0x00, 0x00}, 7, 7, 0, 1},
   {"wacom",  "Wacom tablet",
-           "", M_wacom, NULL, PROTO_WACOM, STD_FLG,
+           "", M_wacom, I_wacom, PROTO_WACOM, STD_FLG,
                                 {0x80, 0x80, 0x80, 0x00}, 7, 7, 0, 0},
 
   {"",     "",
