@@ -43,11 +43,14 @@
 /* this material is needed to pass options to mice.c */
 struct mouse_features mymouse = {
   DEF_TYPE, DEF_DEV, DEF_SEQUENCE,
-  DEF_BAUD, DEF_SAMPLE, DEF_DELTA, DEF_ACCEL, DEF_SCALE,
-  DEF_TIME, DEF_CLUSTER, DEF_THREE, DEF_TOGGLE,
+  DEF_BAUD, DEF_SAMPLE, DEF_DELTA, DEF_ACCEL, DEF_SCALE, DEF_SCALE /*scaley*/,
+  DEF_TIME, DEF_CLUSTER, DEF_THREE, DEF_TOGGLE, DEF_GLIDEPOINT_TAP,
   (Gpm_Type *)NULL
 };
 
+/* and this is a workaroud */
+struct winsize win;
+
 struct mouse_features *which_mouse=&mymouse;
 
 char *prgname;
@@ -71,14 +74,14 @@ struct device {
 static int message(void)
 {
 printf("This program is designed to help you in detecting what type your\n"
-	   "mouse is. Please follow the instructions of this program. If you're\n"
-	   "bored before it is done, you can always press your 'Interrupt' key\n"
-	   "(usually Ctrl-C)\n\n");
+       "mouse is. Please follow the instructions of this program. If you're\n"
+       "bored before it is done, you can always press your 'Interrupt' key\n"
+       "(usually Ctrl-C)\n\n");
 printf("\t *** Remember: don't run any software which reads the mouse device\n"
-	   "\t *** while making this test. This includes \"gpm\","
-	   "\"selection\", \"X\"\n\n");
+       "\t *** while making this test. This includes \"gpm\","
+       "\"selection\", \"X\"\n\n");
 printf("Note that this program is by no means complete, and its main role is\n"
-	   "to detect how does the middle button work on serial mice\n");
+       "to detect how does the middle button work on serial mice\n");
 return 0;
 }
 
@@ -134,7 +137,7 @@ struct device **makedev(struct device **current, char *name)
 {
   int fd;
   if ((fd=open(name,O_RDWR))==-1)
-	{ perror(name); return current; }
+    { perror(name); return current; }
 
   *current=malloc(sizeof(struct device));
   if (!*current) oops("malloc()");
@@ -163,7 +166,7 @@ int noneofthem(void)
 {
   noraw();
   printf("\n\nSomething went wrong, I didn't manage to detect your"
-		 "protocol\n\nFeel free to report your problems to the author\n");
+	 "protocol\n\nFeel free to report your problems to the author\n");
   exit(1);
 }
 
@@ -192,52 +195,52 @@ int eventlist(int fd, char *buff, int buflen, int test, int readstep)
   to.tv_sec=to.tv_usec=0;
 
   switch(test)
-	{
-	case GPM_B_LEFT:
-	  printf("\r\nNow please press and release several times\r\n"
-			 "the left button of your mouse,"
-			 " *** trying not to move it ***\r\n\r\n");
-	  break;
-
-	case GPM_B_MIDDLE:
-	  printf("\r\nNow please press and release several times\r\n"
-			 "the middle button of your mouse,"
-			 " *** trying not to move it ***\r\n\r\n");
-	  break;
-
-	case 0:
-	  printf("\r\nNow please move the mouse around, without pressing any\r\n"
-			 "button. Move it both quickly and slowly\r\n\r\n");
+    {
+    case GPM_B_LEFT:
+      printf("\r\nNow please press and release several times\r\n"
+	     "the left button of your mouse,"
+	     " *** trying not to move it ***\r\n\r\n");
+      break;
+    
+    case GPM_B_MIDDLE:
+      printf("\r\nNow please press and release several times\r\n"
+	     "the middle button of your mouse,"
+	     " *** trying not to move it ***\r\n\r\n");
       break;
 
-	default:
-	  printf("Unknown test to perform\r\n");
-	  return -1;
-	}
+    case 0:
+      printf("\r\nNow please move the mouse around, without pressing any\r\n"
+	     "button. Move it both quickly and slowly\r\n\r\n");
+      break;
+
+    default:
+      printf("Unknown test to perform\r\n");
+      return -1;
+      }
   
   printf("Press any key when you've done enough\r\n");
 
   while(1)
-	{
-	selSet=readySet;
-	if ((pending=select(fd+1,&selSet,NULL,NULL,&to))<0) continue;
-	if (pending==0 && !active) {active++; to.tv_sec=10; continue;}
-	if (pending==0) return got; /* timeout */
+    {
+    selSet=readySet;
+    if ((pending=select(fd+1,&selSet,NULL,NULL,&to))<0) continue;
+    if (pending==0 && !active) {active++; to.tv_sec=10; continue;}
+    if (pending==0) return got; /* timeout */
 
-	if (FD_ISSET(0,&selSet))
-	  { getchar(); if (active) return got; }
-	if (FD_ISSET(fd,&selSet))
-	  { 
-	  if (active) got+=read(fd,buff+got,readstep);
-	  else read(fd,buff,buflen);
-	  }
-	if (got>buflen-readstep)
-	  readstep=buflen-got;
-	if (readstep==0)
-	  got--,readstep++; /* overwrite last char forever */
+    if (FD_ISSET(0,&selSet))
+      { getchar(); if (active) return got; }
+    if (FD_ISSET(fd,&selSet))
+      { 
+      if (active) got+=read(fd,buff+got,readstep);
+      else read(fd,buff,buflen);
+      }
+    if (got>buflen-readstep)
+      readstep=buflen-got;
+    if (readstep==0)
+      got--,readstep++; /* overwrite last char forever */
 
-	to.tv_sec=30;
-	}
+    to.tv_sec=30;
+    }
 }
 		
 
@@ -262,7 +265,7 @@ int main(int argc, char **argv)
 
 
   if (!isatty(fileno(stdin)))
-	{ fprintf(stderr,"%s: stdin: not a tty\n",argv[0]); exit(1); }
+    { fprintf(stderr,"%s: stdin: not a tty\n",argv[0]); exit(1); }
 
   prgname=argv[0];
   message();
@@ -270,27 +273,27 @@ int main(int argc, char **argv)
   /* init the list of possible devices */
 
   for (nextdev=&devlist, i=1; i<argc; i++)
-	nextdev=makedev(nextdev,argv[i]);
+    nextdev=makedev(nextdev,argv[i]);
 
   if (argc==1) /* no cmdline, get all devices */
-	{
-	FILE *f;
-	char s[64];
+    {
+    FILE *f;
+    char s[64];
 
-	f=popen("ls -l /dev/* | "
-			"awk '/^c/ && $5==\"10,\" || $NF ~ \"ttyS[0-3]$\" {print $NF}'",
-			"r");
-	if (!f) oops("popen()");
-	while (fgets(s,64,f))
-	  {
-	  s[strlen(s)-1]='\0'; /* trim '\n' */
-	  nextdev=makedev(nextdev,s);
-	  }
-	pclose(f);
-	}
+    f=popen("ls -l /dev/* | "
+	    "awk '/^c/ && $5==\"10,\" || $NF ~ \"ttyS[0-3]$\" {print $NF}'",
+	    "r");
+    if (!f) oops("popen()");
+    while (fgets(s,64,f))
+      {
+      s[strlen(s)-1]='\0'; /* trim '\n' */
+      nextdev=makedev(nextdev,s);
+      }
+    pclose(f);
+    }
 
   if (devcount==0)
-	{ fprintf(stderr,"%s: no devices found\n",prgname); exit(1); }
+    { fprintf(stderr,"%s: no devices found\n",prgname); exit(1); }
 
   I_serial=mice->init; /* the first one has I_serial */
 
@@ -301,75 +304,75 @@ int main(int argc, char **argv)
 
   trial=0;
   while (devcount>1)
-	{
-	fd_set devSet, gotSet,savSet;
-	struct device *cur;
-	int gotthem;
+    {
+    fd_set devSet, gotSet,savSet;
+    struct device *cur;
+    int gotthem;
 
-	/* BUG */ /* Logitech initialization is not performed */
+    /* BUG */ /* Logitech initialization is not performed */
 
-	opt_baud=BAUD(trial);
-	printf("\r\nTrying with %i baud\r\n",opt_baud);
-	trial++;
+    opt_baud=BAUD(trial);
+    printf("\r\nTrying with %i baud\r\n",opt_baud);
+    trial++;
 
-	FD_ZERO(&devSet); FD_ZERO(&gotSet);
-	FD_SET(fileno(stdin),&devSet); maxfd=fileno(stdin);
-	printf("\r\n The possible device nodes are:\r\n");
-	for (nextdev=&devlist; *nextdev; nextdev=&((*nextdev)->next))
-	  {
-	  printf("\t%s\r\n", (*nextdev)->name);
-	  FD_SET((*nextdev)->fd,&devSet);
-	  maxfd=max((*nextdev)->fd,maxfd);
-	  (*I_serial)((*nextdev)->fd,(mice+1)->flags,mice+1); /* try ms mode */
-	  }
+    FD_ZERO(&devSet); FD_ZERO(&gotSet);
+    FD_SET(fileno(stdin),&devSet); maxfd=fileno(stdin);
+    printf("\r\n The possible device nodes are:\r\n");
+    for (nextdev=&devlist; *nextdev; nextdev=&((*nextdev)->next))
+      {
+      printf("\t%s\r\n", (*nextdev)->name);
+      FD_SET((*nextdev)->fd,&devSet);
+      maxfd=max((*nextdev)->fd,maxfd);
+      (*I_serial)((*nextdev)->fd,(mice+1)->flags,mice+1); /* try ms mode */
+      }
 
-	savSet=devSet;
+    savSet=devSet;
  
-	printf("\r\n\r\nI've still %i devices which may be your mouse,\r\n",
-		   devcount);
-	printf("Please move the mouse. Press any key when done\r\n"
-		   " (You can specify your device name on cmdline, in order to\r\n"
-		   "  avoid this step\r\n. Different baud rates are tried at "
-		   "different times\r\n");
+    printf("\r\n\r\nI've still %i devices which may be your mouse,\r\n",
+	   devcount);
+    printf("Please move the mouse. Press any key when done\r\n"
+	   " (You can specify your device name on cmdline, in order to\r\n"
+	   "  avoid this step\r\n. Different baud rates are tried at "
+	   "different times\r\n");
+    
+    timeout.tv_sec=10; /* max test time */
+    gotthem=0;
+    while (1) /* extract files from the list */
+      {
+      devSet=savSet;
+      if ((pending=select(maxfd+1,&devSet,NULL,NULL,&timeout))<0)
+	continue;
+      if (pending==0 || FD_ISSET(fileno(stdin),&devSet)) {getchar(); break;}
 
-	timeout.tv_sec=10; /* max test time */
-	gotthem=0;
-	while (1) /* extract files from the list */
+      for (nextdev=&devlist; *nextdev; nextdev=&((*nextdev)->next))
+	if (FD_ISSET((*nextdev)->fd,&devSet))
 	  {
-	  devSet=savSet;
-	  if ((pending=select(maxfd+1,&devSet,NULL,NULL,&timeout))<0)
-		continue;
-	  if (pending==0 || FD_ISSET(fileno(stdin),&devSet)) {getchar(); break;}
-
-	  for (nextdev=&devlist; *nextdev; nextdev=&((*nextdev)->next))
-		if (FD_ISSET((*nextdev)->fd,&devSet))
-		  {
-		  gotthem++;
-		  FD_CLR((*nextdev)->fd,&savSet);
-		  FD_SET((*nextdev)->fd,&gotSet);
-		  }
+	  gotthem++;
+	  FD_CLR((*nextdev)->fd,&savSet);
+	  FD_SET((*nextdev)->fd,&gotSet);
 	  }
-	if (gotthem)
-	  for (nextdev=&devlist; *nextdev; /* nothing */ )
-		{
-		cur=*nextdev;
-		if (!FD_ISSET(cur->fd,&gotSet))
-		  {
-		  printf("removing \"%s\" from the list\r\n",cur->name);
-		  *nextdev=cur->next;
-		  close(cur->fd);
-		  free(cur->name);
-		  free(cur);
-		  devcount--;
-		  }
-		else
-		  {
-		  read(cur->fd,buf,80); /* flush */
-		  nextdev=&(cur->next); /* follow list */
-		  }
-		}
-
-	} /* devcount>1 */
+      }
+    if (gotthem)
+      for (nextdev=&devlist; *nextdev; /* nothing */ )
+	{
+	cur=*nextdev;
+	if (!FD_ISSET(cur->fd,&gotSet))
+	  {
+	  printf("removing \"%s\" from the list\r\n",cur->name);
+	  *nextdev=cur->next;
+	  close(cur->fd);
+	  free(cur->name);
+	  free(cur);
+	  devcount--;
+	  }
+	else
+	  {
+	  read(cur->fd,buf,80); /* flush */
+	  nextdev=&(cur->next); /* follow list */
+	  }
+	}
+    
+    } /* devcount>1 */
 
   mousefd=devlist->fd;
   mousename=devlist->name;
@@ -391,50 +394,51 @@ int main(int argc, char **argv)
 
   printf("\r\n\r\nThe possible mouse types are:\r\n");
   for (nextitem=&list, cursor=mice; cursor->fun; cursor++)
-	{
-	*nextitem=malloc(sizeof(struct item));
-	if (!*nextitem) oops("malloc()");
-	(*nextitem)->this=cursor; (*nextitem)->next=NULL;
-	printf("\t%s",cursor->name);
-	if (cursor->syn[0])
-	  printf(" (%s)",cursor->syn);
-	printf("\r\n");
-	typecount++;
-	nextitem=&((*nextitem)->next);
-	}
+    {
+    if (cursor->absolute) continue;
+    *nextitem=malloc(sizeof(struct item));
+    if (!*nextitem) oops("malloc()");
+    (*nextitem)->this=cursor; (*nextitem)->next=NULL;
+    printf("\t%s",cursor->name);
+    if (cursor->syn[0])
+      printf(" (%s)",cursor->syn);
+    printf("\r\n");
+    typecount++;
+    nextitem=&((*nextitem)->next);
+    }
 
 /*====================================== Packet size - first step */
 
   printf("\r\nNow please press and release your left mouse button,\r\n"
-		 "one time only\r\n\r\n");
+	 "one time only\r\n\r\n");
 
   i=read(mousefd,buf,1);
   if (i==-1 && errno==EINVAL) 
-	readamount=3;
+    readamount=3;
   else
-	readamount=1;
+    readamount=1;
 
   usleep(100000);
 
 #define REMOVETYPE(cur,reason) \
-      do { \
-		printf("\tRemoving type \"%s\" because of '%s'\r\n", \
-			   (cur)->this->name,reason); \
-		(*nextitem)=(cur)->next; \
-	    free(cur); \
-        typecount--; \
-      } while(0)
+  do { \
+	 printf("\tRemoving type \"%s\" because of '%s'\r\n", \
+		(cur)->this->name,reason); \
+	 (*nextitem)=(cur)->next; \
+	 free(cur); \
+	 typecount--; \
+       } while(0)
 
 
   for (nextitem=&list; *nextitem; /* nothing */)
-	{
-	struct item *cur=*nextitem;
-	
-	if (readamount!=cur->this->howmany)
-	  REMOVETYPE(cur,"different read() semantics");
-	else
-	  nextitem=&(cur->next);
-	}
+    {
+    struct item *cur=*nextitem;
+    
+    if (readamount!=cur->this->howmany)
+      REMOVETYPE(cur,"different read() semantics");
+    else
+      nextitem=&(cur->next);
+    }
   read(mousefd,buf,BUFLEN); /* flush */
 
 /*====================================== Packet size - second step */
@@ -450,76 +454,76 @@ int main(int argc, char **argv)
 
   packetsize=1; trial=0;
   while (packetsize==1)
-	{
-	int success3=0,success5=0;
+    {
+    int success3=0,success5=0;
 	
-	opt_baud=BAUD(trial);
-	printf("\tBaud rate is %i\r\n",opt_baud);
-	mousefd=mousereopen(mousefd,mousename,NULL);
+    opt_baud=BAUD(trial);
+    printf("\tBaud rate is %i\r\n",opt_baud);
+    mousefd=mousereopen(mousefd,mousename,NULL);
 	
-	printf("\r\n==> Detecting the packet size\r\n");
-	got=eventlist(mousefd,buf,BUFLEN,GPM_B_LEFT,readamount);
+    printf("\r\n==> Detecting the packet size\r\n");
+    got=eventlist(mousefd,buf,BUFLEN,GPM_B_LEFT,readamount);
 	
-	/* try three -- look at repeating arrays of 6 bytes */
-	for (i=0;i<got-12;i++)
-	  if(!memcmp(buf+i,buf+i+6,6))
-		success3++;
+    /* try three -- look at repeating arrays of 6 bytes */
+    for (i=0;i<got-12;i++)
+      if(!memcmp(buf+i,buf+i+6,6))
+	success3++;
 	
-	/* try five -- look at repeating arrays of 10 bytes */
-	for (i=0;i<got-20;i++)
-	  if(!memcmp(buf+i,buf+i+10,10))
-		success5++;
+    /* try five -- look at repeating arrays of 10 bytes */
+    for (i=0;i<got-20;i++)
+      if(!memcmp(buf+i,buf+i+10,10))
+	success5++;
 	
-	printf("matches for 3 bytes: %i   -- matches for 5 bytes: %i\r\n",
-		   success3,success5);
-	if (success3>5 && success5==0)
-	  packetsize=3; 
-	if (success5>5 && success3==0)
-	  packetsize=5;
-	if (packetsize==1)
-	  printf("\r\n ** Ambiguous, try again\r\n");
-	trial++;
-	}
+    printf("matches for 3 bytes: %i   -- matches for 5 bytes: %i\r\n",
+	   success3,success5);
+    if (success3>5 && success5==0)
+      packetsize=3; 
+    if (success5>5 && success3==0)
+      packetsize=5;
+    if (packetsize==1)
+      printf("\r\n ** Ambiguous, try again\r\n");
+    trial++;
+    }
 
 /*====================================== Use that info to discard protocols */
   
   for (nextitem=&list; *nextitem; /* nothing */)
-	{
-	struct item *cur=*nextitem;
-	int packetheads=0;
-	int match=0;
+    {
+    struct item *cur=*nextitem;
+    int packetheads=0;
+    int match=0;
     Gpm_Event event;
 
-	if (packetsize!=cur->this->packetlen)
-	  {
-	  REMOVETYPE(cur,"different packet lenght");
-	  continue;
-	  }
+    if (packetsize!=cur->this->packetlen)
+      {
+      REMOVETYPE(cur,"different packet lenght");
+      continue;
+      }
 
-	/* try to decode button press and release */
+    /* try to decode button press and release */
     for (i=0;i<got;i++)
-	  {
-	  if (   ((buf[i]  &(cur->this->proto)[0]) == (cur->this->proto)[1])
-		  && ((buf[i+1]&(cur->this->proto)[2]) == (cur->this->proto)[3]) )
-		{
-		packetheads++;
-		if ((*(cur->this->fun))(&event,buf+i)==-1)
-		  { packetheads--; continue; }
-		i+=packetsize-1; /* skip packet */
-		if (event.dx || event.dy) continue;
-		if (event.buttons==GPM_B_LEFT)
-		  match++;
-		else if (event.buttons)
-		  match--;
-		}
-	  }
-	if (match<=0)
-	  { REMOVETYPE(cur,"incorrect button detected"); continue;}
-	if (packetheads<got/(packetsize+2))
-		{ REMOVETYPE(cur,"too few events got decoded"); continue; }
-	printf("** type '%s' still possible\r\n",cur->this->name);
-	nextitem=&(cur->next);
+      {
+      if (   ((buf[i]  &(cur->this->proto)[0]) == (cur->this->proto)[1])
+	  && ((buf[i+1]&(cur->this->proto)[2]) == (cur->this->proto)[3]) )
+	{
+	packetheads++;
+	if ((*(cur->this->fun))(&event,buf+i)==-1)
+	  { packetheads--; continue; }
+	i+=packetsize-1; /* skip packet */
+	if (event.dx || event.dy) continue;
+	if (event.buttons==GPM_B_LEFT)
+	  match++;
+	else if (event.buttons)
+	  match--;
 	}
+      }
+    if (match<=0)
+      { REMOVETYPE(cur,"incorrect button detected"); continue;}
+    if (packetheads<got/(packetsize+2))
+      { REMOVETYPE(cur,"too few events got decoded"); continue; }
+    printf("** type '%s' still possible\r\n",cur->this->name);
+    nextitem=&(cur->next);
+    }
 
 /*====================================== It's all done? */
 
@@ -531,13 +535,13 @@ int main(int argc, char **argv)
   
   CHECKFAIL(typecount);
   if (typecount==1)
-	{
-	noraw();
-	printf("\n\n\nWell, it seems like your mouse is already detected:\n"
-		   "it is on the device \"%s\", and speaks the protocol \"%s\"\n",
-		   mousename,list->this->name);
-	exit(0);
-	}
+    {
+    noraw();
+    printf("\n\n\nWell, it seems like your mouse is already detected:\n"
+	   "it is on the device \"%s\", and speaks the protocol \"%s\"\n",
+	   mousename,list->this->name);
+    exit(0);
+    }
 
 /*
  * If it is in the "ms" family, however, three possibilities are still
@@ -545,20 +549,20 @@ int main(int argc, char **argv)
  */
 
   do
-	{
-	printf("\r\nYour mouse is one of the ms family, "
-		   "but do you have the middle button (y/n)? ");
-	putchar(i=getchar()); printf("\r\n");
-	}
+    {
+    printf("\r\nYour mouse is one of the ms family, "
+	   "but do you have the middle button (y/n)? ");
+    putchar(i=getchar()); printf("\r\n");
+    }
   while(i!='y' && i!='n');
 
   if (i=='n')
-	{
-	noraw();
-	printf("\nThen, you should use the \"bare\" protocol on \"%s\"\n",
-		   mousename);
-	exit(0);
-	}
+    {
+    noraw();
+    printf("\nThen, you should use the \"bare\" protocol on \"%s\"\n",
+	   mousename);
+    exit(0);
+    }
 
 /*
  * First trial: remove the "-t ms" extension if spurious buttons come in
@@ -578,11 +582,11 @@ int main(int argc, char **argv)
           && ((buf[i+1]&(cur->this->proto)[2]) == (cur->this->proto)[3]) )
         {
         if ((*(cur->this->fun))(&event,buf+i)==-1) continue;
-		i+=packetsize-1;
-		if (event.buttons) pending--;
+	i+=packetsize-1;
+	if (event.buttons) pending--;
         }
       }
-	if (pending<0) { REMOVETYPE(cur,"spurious button reported"); continue; }
+    if (pending<0) { REMOVETYPE(cur,"spurious button reported"); continue; }
     printf("** type '%s' still possible\r\n",cur->this->name);
     nextitem=&(cur->next);
     }
@@ -599,15 +603,15 @@ int main(int argc, char **argv)
 
   /* if it uses the 4-byte protocol, find it in a rude way */
   for (pending=0,i=0;i<got-16;i++)
-	if(!memcmp(buf+i,buf+i+8,8))
-	  pending++;
+    if(!memcmp(buf+i,buf+i+8,8))
+      pending++;
   if (pending>3)
-	{
-	noraw();
-	printf("\nYour mouse seems to be a 'mman' one  on \"%s\" (%i matches)\n",
-		   mousename,pending);
-	exit(0);
-	}
+    {
+    noraw();
+    printf("\nYour mouse seems to be a 'mman' one  on \"%s\" (%i matches)\n",
+	   mousename,pending);
+    exit(0);
+    }
 
   pending=0;
   for (nextitem=&list; *nextitem; /* nothing */)
@@ -625,8 +629,8 @@ int main(int argc, char **argv)
         i+=packetsize-1;
         if (event.buttons && event.buttons!=GPM_B_MIDDLE)
           pending--;
-		if (event.buttons==GPM_B_MIDDLE)
-		  pending++;
+	if (event.buttons==GPM_B_MIDDLE)
+	  pending++;
         }
       }
 	if (pending<0)
@@ -635,7 +639,7 @@ int main(int argc, char **argv)
 	  {
 	  noraw();
 	  printf("\nYour mouse seems to be a '%s' one on \"%s\" (%i matches)\n",
-			 cur->this->name,mousename,pending);
+		 cur->this->name,mousename,pending);
 	  exit(0);
 	  }
 	printf("** type '%s' still possible\r\n",cur->this->name);
@@ -659,26 +663,26 @@ int main(int argc, char **argv)
   printf("\r\nSome mice change protocol to three-buttons-aware if some\r\n"
 		 "\r\ncontrol lines are toggled after opening\r\n");
   for (index=0;index<3;index++)
-	{
-	mousereopen(mousefd,mousename,NULL);
-	lines = alllines & ~toggle[index];
-	ioctl(mousefd, TIOCMSET, &lines);
-	printf("\r\n==> Trying with '-o %s'\r\n",tognames[index]);
-	got=eventlist(mousefd,buf,BUFLEN,GPM_B_MIDDLE,readamount);
-
-	/* if it uses the 5-byte protocol, find it in a rude way */
-	for (pending=0,i=0;i<got-20;i++)
-	  if(!memcmp(buf+i,buf+i+10,10))
-		pending++;
-	if (pending>3)
-	  {
-	  noraw();
-	  printf("\nYour mouse becomes a 3-buttons ('-t msc') one when\n"
-			 "gpm gets '-o %s' on it command line, and X gets\n"
-			 "%s in XF86Config\nThe device is \"%s\"",
-			 tognames[index],Xtognames[index],mousename);
-	  exit(0);
-	  }
+    {
+    mousereopen(mousefd,mousename,NULL);
+    lines = alllines & ~toggle[index];
+    ioctl(mousefd, TIOCMSET, &lines);
+    printf("\r\n==> Trying with '-o %s'\r\n",tognames[index]);
+    got=eventlist(mousefd,buf,BUFLEN,GPM_B_MIDDLE,readamount);
+    
+    /* if it uses the 5-byte protocol, find it in a rude way */
+    for (pending=0,i=0;i<got-20;i++)
+      if(!memcmp(buf+i,buf+i+10,10))
+	pending++;
+    if (pending>3)
+      {
+      noraw();
+      printf("\nYour mouse becomes a 3-buttons ('-t msc') one when\n"
+	     "gpm gets '-o %s' on it command line, and X gets\n"
+	     "%s in XF86Config\nThe device is \"%s\"",
+	     tognames[index],Xtognames[index],mousename);
+      exit(0);
+      }
     }
   }
 /*
@@ -687,13 +691,13 @@ int main(int argc, char **argv)
  */
 
   printf("\r\nYour damned device doesn't respond to anything\r\n"
-		 "the only remaining possibility is to keep presses the middle\r\n"
-		 "button _while_the_mouse_is_being_opened. This is the worst thing\r\n"
-		 "ever thought after caps-lock-near-the-A\r\n");
+	 "the only remaining possibility is to keep presses the middle\r\n"
+	 "button _while_the_mouse_is_being_opened. This is the worst thing\r\n"
+	 "ever thought after caps-lock-near-the-A\r\n");
 
   printf("\r\nNow please press the middle button, and then press any key\r\n"
-		 "while keeping the button down. Wait to release it until the\r\n"
-		 "next message.\r\n");
+	 "while keeping the button down. Wait to release it until the\r\n"
+	 "next message.\r\n");
 	
   getchar();
 
@@ -701,25 +705,20 @@ int main(int argc, char **argv)
 
   /* if it uses the 5-byte protocol, find it in a rude way */
   for (pending=0,i=0;i<got-20;i++)
-	if(!memcmp(buf+i,buf+i+10,10))
-	  pending++;
+    if(!memcmp(buf+i,buf+i+10,10))
+      pending++;
   if (pending>3)
-	{
-	noraw();
-	printf("\nWorked. You should keep the button pressed every time the\n"
-		   "computer boots, and run gpm in '-R' mode in order to ignore\n"
-		   "such hassle when starting X\n\nStill better, but a better mouse\n"
-		   "\nThe current mouse device is \"%s\"\n",mousename);
+    {
+    noraw();
+    printf("\nWorked. You should keep the button pressed every time the\n"
+	   "computer boots, and run gpm in '-R' mode in order to ignore\n"
+	   "such hassle when starting X\n\nStill better, but a better mouse\n"
+	   "\nThe current mouse device is \"%s\"\n",mousename);
 
-	exit(0);
-	}
+    exit(0);
+    }
   noraw();
-  printf("\nI'm lost. Can't help you\n");
+  printf("\nI'm lost. Can't tell you how to use your middle button\n");
 return 0;
 }
 
-
-
-
-
-
