@@ -48,8 +48,8 @@
 #endif
 
 #define RMEV_NAME "Mev"
-#define RMEV_RELEASE "1.09"
-#define RMEV_DATE "May 1996"
+#define RMEV_RELEASE "1.10"
+#define RMEV_DATE "July 1996"
 
 
 /*===================================================================*/
