@@ -25,7 +25,7 @@
 
 /*========== the WD macro prints on stderr to help tracing program flow =*/
 
-#if defined DEBUG || defined DEBUGG
+#if defined DEBUG
 #  ifdef TCL_MEM_DEBUG
 #  define WD (fprintf(stderr,"  File " __FILE__ "(%i)\n", __LINE__),\
                Tcl_ValidateAllMemory(__FILE__,__LINE__))
@@ -33,27 +33,20 @@
 #  define WD fprintf(stderr,"File " __FILE__ "(%i)\n", __LINE__)
 #  endif
 #else
-#define WD 0
+#define WD 
 #endif
 
-/*========== the DEBUGG symbol is redefined to enable hidden code =======*/
 
-#ifdef DEBUGG
-#undef DEBUGG
-#define DEBUGG(data) fprintf data
-#define DEBUG
-#else
-#define DEBUGG(data)
-#endif
-
-/*========== the DEBUG symbol is weaker, and is enabled by DEBUGG =======*/
+/*========== the PDEBUG symbol masks fprintf =======*/
 
 #ifdef DEBUG
-#undef DEBUG
-#define DEBUG(data) fprintf data
-#define DEBUGGING
+#define PDEBUG(data) fprintf data
 #else
-#define DEBUG(data) 0
+#define PDEBUG(data)
 #endif
 
+/*========== the PDEBUGG symbol hides everything =======*/
+
+#define PDEBUGG(data)
+
 #endif /* _WD_H_ */
